mercurial/localrepo.py
changeset 31024 0b8356705de6
parent 30989 74af89c66834
child 31025 6cf2857526c7
--- a/mercurial/localrepo.py	Sun Feb 19 18:16:09 2017 +0900
+++ b/mercurial/localrepo.py	Sun Feb 19 18:19:33 2017 +0900
@@ -50,6 +50,7 @@
     pushkey,
     repoview,
     revset,
+    revsetlang,
     scmutil,
     store,
     subrepo,
@@ -573,7 +574,7 @@
         '''Find revisions matching a revset.
 
         The revset is specified as a string ``expr`` that may contain
         %-formatting to escape certain types. See ``revset.formatspec``.
 
         Revset aliases from the configuration are not expanded. To expand
         user aliases, consider calling ``scmutil.revrange()``.
@@ -581,7 +582,7 @@
         Returns a revset.abstractsmartset, which is a list-like interface
         that contains integer revisions.
         '''
-        expr = revset.formatspec(expr, *args)
+        expr = revsetlang.formatspec(expr, *args)
         m = revset.match(None, expr)
         return m(self)
@@ -573,7 +574,7 @@
 
         The revset is specified as a string ``expr`` that may contain
-        %-formatting to escape certain types. See ``revset.formatspec``.
+        %-formatting to escape certain types. See ``revsetlang.formatspec``.
 
         Revset aliases from the configuration are not expanded. To expand